Attribute VB_Name = "NS_Ecology_xls_Macros"
'NatureServe Ecology Custom Excel Macros
'-----------------------------------------------------
'(For custom functions, use the add-in Natureserve.xla*)
'
'Installation: Import this module into your personal.xls and store it in your XLStart folder
'Or just replace your personal.xls with this one.
'
'Contains the following:
'1. Add_quotes macro:
'       'Enclose in single quotes, replace ' with '', and trim outside spaces
'         (to prepare text for SQL insert statements)
'
'2. Fill_column macro:
'       Fill empty cells in selection with preceding value in COLUMN (top to bottom)
'
'3. Fill_row macro:
'       Fill empty cells in selection with preceding value in ROW (left to right)
'
'Tip: You can add toolbar buttons for macros you use regularly.

Sub Add_quotes()
'For data in each selected cell,
'enclose in single quotes, replace ' with '', and trim outside spaces
'(to prepare text for SQL insert statements)

For Each c In Selection.Cells
  If IsNull(c.Value) Or Trim(c.Value) = "" Then
    c.Value = "Null"
  Else
    c.Value = "''" & Replace(Trim(c.Value), "'", "''") & "'"
  End If
Next c

End Sub

Sub Fill_column()
'Fill empty cells in selection with preceding value in COLUMN (top to bottom)

For Each c In Selection.Cells
  If IsNull(c.Value) Or Trim(c.Value) = "" Then
    c.Value = c.Offset(-1, 0)
  End If
Next c

End Sub

Sub Fill_row()
'Fill empty cells in selection with preceding value in ROW (left to right)

For Each c In Selection.Cells
  If IsNull(c.Value) Or Trim(c.Value) = "" Then
    c.Value = c.Previous.Value
  End If
Next c

End Sub



'From Excel Help:
'Making your custom functions available anywhere
'To use a custom function, the workbook containing the module in which you
'create the function must be open. If that workbook is not open, you get a
'#NAME? error when you try to use the function. Even if the workbook is open, '
'if you use the function in a different workbook, you must precede the function
'name with the name of the workbook in which the function resides. For example,
'if you create a function called Discount in a workbook called Personal.xls, and
'you call that function from another workbook, you must write
'=personal.xls!Discount(), not simply =Discount().

'You can save yourself some keystrokes (and possible typing errors) by selecting
'your custom functions from the Insert Function dialog box. (Your custom functions
'appear in the User Defined category.) An easier way to make your custom functions
'available at all times is to store them in a separate workbook and then save that
'workbook as an add-in (an XLA file) in your XLStart folder. (The XLStart folder
'is a subfolder of the folder containing your Excel files. When you start Excel,
'the program opens any documents it finds in XLStart.) To save a workbook as an
'add-in, choose File, Save As (or File, Save). Then choose Microsoft Excel
'Add-in from the Files Of Type list.

'If your user-defined functions are stored in an XLA file that is present in
'memory, you don't have to specify the name of that file when you call a function.
'If the XLA file is saved in your XLStart folder, it will be present in memory
'whenever you run Excel.

'****************
'*Note from ksnow:
'As far as I can tell, an XLA file in the XLStart folder
'DOES work to keep functions always available but DOES NOT work for macros!

'Macros are always available if stored in personal.xls, but functions aren't!
'I don't understand this but the bottom line is:
'1. Store functions as an add-in (XLA) in the XLStart folder
'2. Store macros in personal.xls in the XLStart folder.  (It may be ok if it's in the Add-In folder and installed.)
'****************
